@@ -417,6 +417,12 @@ class TAXII2Server(BaseTAXIIServer):
         }
         return make_taxii2_response(response, status=400)
 
+    def raise_unauthorized(self):
+        """
+        Handle unauthorized access.
+        """
+        raise Unauthorized()
+
     def get_endpoint(self, relative_path: str) -> Optional[Callable[[], Response]]:
         endpoint = None
         for regex, handler in self.ENDPOINT_MAPPING:
@@ -468,8 +474,10 @@ class TAXII2Server(BaseTAXIIServer):
         self.check_headers(endpoint)
         return endpoint()
 
-    @register_handler(r"^/taxii2/$")
+    @register_handler(r"^/taxii2/$", handles_own_auth=True)
     def discovery_handler(self):
+        if context.account is None and not self.config["public_discovery"]:
+            raise Unauthorized()
         response = {
             "title": self.config["title"],
         }
@@ -478,16 +486,20 @@ class TAXII2Server(BaseTAXIIServer):
                 response[key] = self.config.get(key)
         default_api_root, api_roots = self.persistence.get_api_roots()
         if default_api_root:
-            response["default"] = f"/{default_api_root.id}/"
-        response["api_roots"] = [f"/{api_root.id}/" for api_root in api_roots]
+            response["default"] = f"/taxii2/{default_api_root.id}/"
+        response["api_roots"] = [f"/taxii2/{api_root.id}/" for api_root in api_roots]
         return make_taxii2_response(response)
 
-    @register_handler(r"^/(?P<api_root_id>[^/]+)/$")
+    @register_handler(r"^/taxii2/(?P<api_root_id>[^/]+)/$", handles_own_auth=True)
     def api_root_handler(self, api_root_id):
         try:
             api_root = self.persistence.get_api_root(api_root_id=api_root_id)
         except DoesNotExistError:
+            if context.account is None:
+                raise Unauthorized()
             raise NotFound()
+        if context.account is None and not api_root.is_public:
+            raise Unauthorized()
         response = {
             "title": api_root.title,
             "versions": ["application/taxii+json;version=2.1"],
@@ -497,40 +509,29 @@ class TAXII2Server(BaseTAXIIServer):
             response["description"] = api_root.description
         return make_taxii2_response(response)
 
-    @register_handler(r"^/(?P<api_root_id>[^/]+)/status/(?P<job_id>[^/]+)/$")
+    @register_handler(r"^/taxii2/(?P<api_root_id>[^/]+)/status/(?P<job_id>[^/]+)/$")
     def job_handler(self, api_root_id, job_id):
         try:
-            job, job_details = self.persistence.get_job_and_details(
+            job = self.persistence.get_job_and_details(
                 api_root_id=api_root_id, job_id=job_id
             )
         except DoesNotExistError:
             raise NotFound()
-        response = {
-            "id": job.id,
-            "status": job.status,
-            "request_timestamp": taxii2_datetimeformat(job.request_timestamp),
-            "total_count": job_details.total_count,
-            "success_count": len(job_details.success),
-            "successes": [
-                job_detail.as_taxii2_dict() for job_detail in job_details.success
-            ],
-            "failure_count": len(job_details.failure),
-            "failures": [
-                job_detail.as_taxii2_dict() for job_detail in job_details.failure
-            ],
-            "pending_count": len(job_details.pending),
-            "pendings": [
-                job_detail.as_taxii2_dict() for job_detail in job_details.pending
-            ],
-        }
+        response = job.as_taxii2_dict()
         return make_taxii2_response(response)
 
-    @register_handler(r"^/(?P<api_root_id>[^/]+)/collections/$")
+    @register_handler(
+        r"^/taxii2/(?P<api_root_id>[^/]+)/collections/$", handles_own_auth=True
+    )
     def collections_handler(self, api_root_id):
         try:
-            self.persistence.get_api_root(api_root_id=api_root_id)
+            api_root = self.persistence.get_api_root(api_root_id=api_root_id)
         except DoesNotExistError:
+            if context.account is None:
+                raise Unauthorized()
             raise NotFound()
+        if context.account is None and not api_root.is_public:
+            raise Unauthorized()
         collections = self.persistence.get_collections(api_root_id=api_root_id)
         response = {}
         if collections:
@@ -551,7 +552,7 @@ class TAXII2Server(BaseTAXIIServer):
         return make_taxii2_response(response)
 
     @register_handler(
-        r"^/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/$",
+        r"^/taxii2/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/$",
         handles_own_auth=True,
     )
     def collection_handler(self, api_root_id, collection_id_or_alias):
@@ -579,7 +580,7 @@ class TAXII2Server(BaseTAXIIServer):
         return make_taxii2_response(response)
 
     @register_handler(
-        r"^/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/manifest/$",
+        r"^/taxii2/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/manifest/$",
         handles_own_auth=True,
     )
     def manifest_handler(self, api_root_id, collection_id_or_alias):
@@ -624,7 +625,7 @@ class TAXII2Server(BaseTAXIIServer):
         )
 
     @register_handler(
-        r"^/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/objects/$",
+        r"^/taxii2/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/objects/$",
         ("GET", "POST"),
         valid_content_types=("application/taxii+json;version=2.1",),
         handles_own_auth=True,
@@ -679,9 +680,11 @@ class TAXII2Server(BaseTAXIIServer):
         )
 
     def objects_post_handler(self, api_root_id, collection_id_or_alias):
-        validate_envelope(request.data)
+        validate_envelope(
+            request.data, allow_custom=self.config.get("allow_custom_properties", True)
+        )
         try:
-            job, job_details = self.persistence.add_objects(
+            job = self.persistence.add_objects(
                 api_root_id=api_root_id,
                 collection_id_or_alias=collection_id_or_alias,
                 data=request.get_json(),
@@ -690,24 +693,7 @@ class TAXII2Server(BaseTAXIIServer):
             if context.account is None:
                 raise Unauthorized()
             raise NotFound()
-        response = {
-            "id": job.id,
-            "status": job.status,
-            "request_timestamp": taxii2_datetimeformat(job.request_timestamp),
-            "total_count": job_details.total_count,
-            "success_count": len(job_details.success),
-            "successes": [
-                job_detail.as_taxii2_dict() for job_detail in job_details.success
-            ],
-            "failure_count": len(job_details.failure),
-            "failures": [
-                job_detail.as_taxii2_dict() for job_detail in job_details.failure
-            ],
-            "pending_count": len(job_details.pending),
-            "pendings": [
-                job_detail.as_taxii2_dict() for job_detail in job_details.pending
-            ],
-        }
+        response = job.as_taxii2_dict()
         headers = {}
         return make_taxii2_response(
             response,
@@ -716,7 +702,7 @@ class TAXII2Server(BaseTAXIIServer):
         )
 
     @register_handler(
-        r"^/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/objects/(?P<object_id>[^/]+)/$",
+        r"^/taxii2/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)/objects/(?P<object_id>[^/]+)/$",
         ("GET", "DELETE"),
         handles_own_auth=True,
     )
@@ -797,7 +783,7 @@ class TAXII2Server(BaseTAXIIServer):
 
     @register_handler(
         (
-            r"^/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)"
+            r"^/taxii2/(?P<api_root_id>[^/]+)/collections/(?P<collection_id_or_alias>[^/]+)"
             r"/objects/(?P<object_id>[^/]+)/versions/$"
         ),
         handles_own_auth=True,
